#[non_exhaustive]pub struct FollowRelationship {
pub followed_at: Timestamp,
pub from_id: UserId,
pub from_name: DisplayName,
pub from_login: UserName,
pub to_id: UserId,
pub to_name: DisplayName,
pub to_login: UserName,
}Available on crate feature
helix only.Expand description
Describes a follow relationship
Used in UsersFollows
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.followed_at: TimestampDate and time when the from_id user followed the to_id user.
from_id: UserIdID of the user following the to_id user.
from_name: DisplayNameDisplay name corresponding to from_id.
from_login: UserNameLogin of the user following the to_id user.
to_id: UserIdID of the user being followed by the from_id user.
to_name: DisplayNameDisplay name corresponding to to_id.
to_login: UserNameLogin of the user being followed by the from_id user.